<?php 
$lan = array(

  'subscribe pages' => 'P&aacute;ginas de Inscri&ccedil&atilde;o',
  'deleted' => 'Apagada',
  'add_new' => 'Adicionar uma nova',
  'title' => 't&iacute;tulo',
  'edit' => 'editar',
  'del' => 'apagar',
  'view' => 'exibir',
  'status' => 'estatus',
  'owner' => 'administrador',
  'default' => 'padr&atilde;o',
  'active' => 'ativa',
  'not active' => 'inativa',

);
?>
